@@ -2,16 +2,17 @@ from pathlib import Path
 import shutil
 import subprocess, os, filecmp
 import unittest
+import sys
 
 
 class test_basics(unittest.TestCase):
     this_dir = os.path.dirname(__file__)
-    data_dir = this_dir + '\\data'
-    tmp_dir = this_dir + '\\tmp'
-    src = tmp_dir + '\\src.h'
-    dest = tmp_dir + '\\dest.h'
-    srcin = data_dir + '\\src.h.in'
-    destin = data_dir + '\\dest.h.in'
+    data_dir = os.path.join(this_dir, 'data')
+    tmp_dir = os.path.join(this_dir, 'tmp')
+    src = os.path.join(tmp_dir, 'src.h')
+    dest = os.path.join(tmp_dir, 'dest.h')
+    srcin = os.path.join(data_dir, 'src.h.in')
+    destin = os.path.join(data_dir, 'dest.h.in')
 
     def setUp(self):
         shutil.rmtree(self.tmp_dir, ignore_errors=True)
@@ -23,7 +24,11 @@ class test_basics(unittest.TestCase):
         shutil.rmtree(self.tmp_dir, ignore_errors=True)
 
     def test_basics(self):
-        subprocess.run(['editcpp', '--src-file', self.src, '--dest-file', self.dest, '--oldfile-keep', '-std=c++03'])
+        os.environ["PATH"] += os.pathsep + os.path.dirname(sys.executable)
+        guts_env = os.environ.copy()
+        guts_env["PATH"] += os.pathsep + os.path.dirname(sys.executable)
+        subprocess.run(['editcpp', '--src-file', self.src, '--dest-file', self.dest, 
+        '--oldfile-keep', '-std=c++03'], env=guts_env)
 
         with open(self.dest) as f:
             with open(self.destin) as fin:
